.. syglass documentation master file, created by
   sphinx-quickstart on Tue Dec 18 12:16:03 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

syGlass Developer API
===================================

The Python module ``syglass`` allows scientists and developers alike to create powerful custom workflows to leverage their `syGlass <https://www.syglass.io/>`_ image volumes and annotations.

Here you'll find detailed examples and documentation to help get you started.

Content Overview
----------------

.. toctree::
   :maxdepth: 3
   
   installation
   examples
   faqs
   
Detailed Documentation
-----------------------

* :ref:`genindex`
